var PUSH_API_KEY    = "";
var PUSH_SENDER_ID  = "";
var TABLE_PUSH_DATA = "";
var debug = false;
var saveRegData = false;
var db;

var onAPIRegistered;
var onPushServerRegistered;
var onMessageReceived;
var onPushError;
var onUnknownEvent;
var badgeSuccessHandler = function(){};
var badgeErrorHandler = function(){};



var activeDebugMode = function(debugOn){
    debug = debugOn;
}

var findPushDataInDatabase = function(success, failure) {
    getDbData(TABLE_PUSH_DATA, 0, success, failure);
}

var savePushDataInDatabase = function(object, success, failure){	
	  object.id = 0;
    setDbData(TABLE_PUSH_DATA, object, success, failure);
}

var registerInPushServer = function(pushData, success){
	var params = [];
    params[0] = pushData.apiKey;
    params[1] = pushData.regId;

    var successCallback = function(){
      var msg = "Registro no servidor de mensagens: Registro realizado com sucesso";
      console.log(msg);

      if (debug) 
      	mInfo(msg);

      if (success)
        success();
    };

    var failCallback = function(){
      var msg = "Registro no servidor de mensagens: Falha ao realizar registro";
      console.error(msg);

      if (debug)
      	mError(msg);
    };

    wsGet('push_test','register',params,successCallback,failCallback) ;
}


/*------------------------------------------------------
                    Push Events
--------------------------------------------------------*/

var onRegistered = function(regId){
	if ( regId.length > 0 ) {

        console.log("Push Service: Api Key = " + PUSH_API_KEY);
        console.log("Push Service: registration id = " + regId);

        var pushData = new Object();
        pushData.apiKey = PUSH_API_KEY;
        pushData.regId  = regId;

        if ((saveRegData) && db) {
          var success = function(){
            var msg = "Armazenamento Local: Dados de acesso ao PushService (api key e registration id) salvos com sucesso";
            console.log(msg);
            pushServiceData = pushData;

            if (debug)
              mInfo(msg);
          };
          var fail = function(){
            var msg = "Armazenamento Local: Falha ao armazenar dados de acesso ao push service (api key e registration id)";
            console.error(msg);

            if (debug)
              mError(msg);
          };
          savePushDataInDatabase(pushData, success, fail);
        }
    }
    if (onAPIRegistered)
      onAPIRegistered(regId);
}



onNotificationGCM = function(e) {
    switch( e.event ){
        case 'registered':
          onRegistered(e.regid);          
        break;

        case 'message':            
          if (onMessageReceived)
            onMessageReceived(e.message, e.msgcnt);
        break;

        case 'error':
          if (onPushError)
            onPushError(e.msg);
        break;  

        default:
          if (onUnknownEvent)
            onUnknownEvent(e);
        break;
    }
}

onNotificationAPN = function(e){
    if (e.alert){
      if (onMessageReceived) 
            onMessageReceived(e.alert, e.badge);
    }

    if (e.sound){
        var snd = new Media(event.sound);
        snd.play();
    }

    if (e.badge){
        pushNotification.setApplicationIconBadgeNumber(function(){}, function(){}, event.badge);
    }
}

//---------------------------------------------------------------------
//             Operações Básicas
//---------------------------------------------------------------------


/**
 * Inicializa a api
 * @Param {String} apiKey chave de acesso da api GCM
 * @param {String} senderId sender id da api GCM
 * @param {Database|undefined} dataBase um database Web SQL aberto, para ser utilizado para armazenar os dados do Push (opcional)
 * @param {String|undefined} nome para a tabela que irá armazenar os dados do Push Service no web SQL.
 *                           se não informado, assume o nome "push_data"  (opcional)
 */
var pushBusinessInit = function(apiKey, senderId, dataBase, pushDataTableName){
    PUSH_API_KEY    = apiKey;
    PUSH_SENDER_ID  = senderId;
    saveRegData = false;
    if (dataBase){
        db = dataBase;
        saveRegData = true;
        db.transaction(function(transaction){
            transaction.executeSql("CREATE TABLE IF NOT EXISTS "+TABLE_PUSH_DATA+" (id UNIQUE,value)");  
        });        
    }
    if (!pushDataTableName)
      TABLE_PUSH_DATA = 'push_data'
    else
      TABLE_PUSH_DATA = pushDataTableName;    
}


/**
 * Registra o aplicativo para utilizar Push Messages, com base nos dados inicializados no método "pushBusinessInit"
 */
var registerPushService = function(){    
    try {
      var successHandler = function(result) {    
          var msg = "Push Service: Sucesso ao registrar Push Service. Result = " + result;
          console.log(msg);

          if (debug)
            mInfo(msg);
      }
      var errorHandler = function(error) {
          var msg = "Push Service: Falha ao registrar Push Service.";
          console.error(msg);

          if (debug)
            mError(msg);
      }

      var pushNotification = window.plugins.pushNotification;
      if (device.platform == 'android' || device.platform == 'Android') {
                
        console.log("Push Service: Registrando serviço com Sender Id = " + PUSH_SENDER_ID + "...");
        pushNotification.register(successHandler, errorHandler,{"senderID" : PUSH_SENDER_ID,"ecb" : "onNotificationGCM"});

      }else{//IOS

        pushNotification.register(onRegistered, errorHandler,{"badge":"true", "sound":"true", "alert":"true", "ecb":"onNotificationAPN"});

      }
    } catch(e) {
      if (debug)
        mError(e.message);
      console.error("Push Service: Erro desconhecido ao registrar PushService. Erro = " + e);
      mError("Push Service: Erro desconhecido ao registrar PushService. Erro = " + e.message);
    }
 }

/**
 * Registra um listener para o evento disparado ao registrar junto à GCM
 * @param {function} callback a função a ser chamada ao registrar com sucesso junto a GCM. 
 *                            Deve receber um parâmetro: o regId associado ao device
 */
var pushSetupOnRegisterListener = function(callback){
    onAPIRegistered = callback;
}


/**
 * Registra um listener para o evento disparado ao receber uma mensagem push
 * @param {function} callback a função a ser chamada ao receber a mensagem 
 *                            Deve receber dois parâmetros: A mensagem e o msgCnt
 */
var pushSetupOnMessageReceivedListener = function(callback){
  onMessageReceived = callback;
}

/**
 * Registra um listener para o evento disparado ao ocorrer algum erro referente ao Push Service (Android apenas)
 * @param {function} callback a função a ser chamada ao ocorrer o erro
 *                            Deve receber um parâmetro: A mensagem de erro
 */
var pushSetupOnErrorListener = function(callback){
  onPushError = callback;
}

/**
 * Registra um listener para o evento desconhecido referente à GCM (Android apenas)
 * @param {function} callback a função a ser chamada ao ocorrer um evento desconhecido
 *                            Deve receber um parâmetro: o evento
 */
var pushSetupUnknownEventListener = function(callback){
  onUnknownEvent = callback;
}

/**
 * Registra um callback para o caso de haver sucesso ao inserir um badge (Apenas IOS)
 */
var pushSetupIosBadgeSuccessHandler = function(callback){
  badgeSuccessHandler = callback;
}

/**
 * Registra um callback para o caso de haver falha ao inserir um badge (Apenas IOS)
 */
var pushSetupIosBadgeErrorHandler = function(callback){
  badgeErrorHandler = callback;
} 

/**
 * @return {String|undefined} o regId, caso esteja registrado; ou undefined, caso contrário
 */
var getRegId = function(callback){
    findPushDataInDatabase(
        function(d){
          if(d)
            callback(d.regId);
          else
            callback(undefined);
        },
        function(){
          callback(undefined);
        }
    );
}