var Twitter = new function(){
	var oauth_consumer_key;
	var oauth_consumer_secret;
	var oauth_nonce;
	var oauth_signature;
	var oauth_signature_method = 'HMAC-SHA1';
	var oauth_timestamp;
	var oauth_token;
	var oauth_version = '1.0';

	var CALLBACK_URL = 'http://www.williamazevedodepaula.com.br';


	/**
	 * Inicializa o utilitário Twitter.
	 *
	 * @param consumer_key - consumer_key da aplicação
	 * @param consumer_secret - consumer_secret da aplicação
	 */
	this.init = function(consumer_key,consumer_secret) {
		oauth_consumer_key    = consumer_key;
		oauth_consumer_secret = consumer_secret;
	}

	/**
	 * Solicita um request Token ao twitter. Se a requisição ocorrer com sucesso,
	 * invoca um successCallback passando como parâmetro o token e o token_secret
	 *
	 * @param successCallback - callback a ser executado caso a requisição seja bem sucedida. Recebe dois parâmetros:
	 *        - Token de acesso
	 *        - Segredo do token de acesso
	 * @param failCallback - Callback a ser invocado caso ocorra um erro ao processar a requisição.  
	 */
	this.requestToken = function(successCallback,failCallback){
		var param   = new Object();
		param.key   = 'oauth_callback';
		param.value = CALLBACK_URL;
		var params = [];
		params.push(param);

		var success = function(data){
			if(data){
				while (data.indexOf('&') != -1) {
 					data = data.replace('&', '","');
				}
				while (data.indexOf('=') != -1) {
 					data = data.replace('=', '":"');
				}
				var objData = JSON.parse('{"'+data+'"}');

				if(objData.oauth_callback_confirmed){
					successCallback(objData.oauth_token,objData.oauth_token_secret);
				}
			}
		};

		var errorCallback = failCallback;
		if(!errorCallback){
			errorCallback = function(){
				mAlert('Falha na conexão com o Twitter.');
			};
		}
		
		
		var authReader = generateAuthorizationHeader(null,null,'post','https://api.twitter.com/oauth/request_token',params);
		$.ajax({
	        url:'https://api.twitter.com/oauth/request_token',
	        type:'post',
	        headers:{
	        	"Authorization": authReader
	        },
	        success:success,
	        error:errorCallback
	    }); 
	
	}


	/**
	 * Direciona o usuário para a tela de autenticação do Twitter e, após realização do login com sucesso,
	 * invoca um successCallback passando como parâmetro o token e o token_verifier
	 *
	 * @param token - token de acesso temporário obtido através do método requestToken
	 * @param successCallback - callback a ser executado caso a autenticação seja bem sucedida. Recebe dois parâmetros:
	 *        - Token definitivo de acesso
	 *        - verificador do acesso
	 */
	this.authenticate = function(token, successCallback){

		var twitterLogin = window.open('https://api.twitter.com/oauth/authenticate?oauth_token='+token,'_blank','location=no');
		
		twitterLogin.addEventListener('loadstart',function(event){            
            if(event.url.substr(0,CALLBACK_URL.length)===CALLBACK_URL){
                if(event.url.indexOf('oauth_token')>0){
                	var data = event.url.substr(event.url.indexOf('?')+1);
                    while (data.indexOf('&') != -1) {
	 					data = data.replace('&', '","');
					}
					while (data.indexOf('=') != -1) {
	 					data = data.replace('=', '":"');
					}
					var objData = JSON.parse('{"'+data+'"}');

					successCallback(objData.oauth_token,objData.oauth_verifier);
                }
                twitterLogin.close();
            }
        });
	}


	/**
	 * Converte o request token em access token, utilizando o verifier gerado ao autenticar 
	 *
	 * @param request_token - O token temporário a ser convertido, obtido através do método requestToken
	 * @param verifier - O verificador obtido através da autenticação
	 * @param successCallback - callback a ser executado caso a operação seja bem sucedida. Recebe 
	 *                          o access token gerado como parâmetro.
	 * @param .failCallback - Callback a ser executado caso haja uma falha ao executar a operação.
	 *                       Caso não seja informado, o tratamento padrão é utilizado   
	 */
	this.generateAccessToken = function(request_token,verifier,successCallback,failCallback){
		var param   = new Object();
		param.key   = 'oauth_verifier';
		param.value = verifier;
		var params = [];
		params.push(param);

		var success = function(data){
			if(data){
				while (data.indexOf('&') != -1) {
 					data = data.replace('&', '","');
				}
				while (data.indexOf('=') != -1) {
 					data = data.replace('=', '":"');
				}
				var objData = JSON.parse('{"'+data+'"}');

				successCallback(objData.oauth_token,objData.oauth_token_secret,objData.screen_name);				
			}
		};

		var errorCallback = failCallback;
		if(!errorCallback){
			errorCallback = function(){
				mAlert('Falha na conexão com o Twitter.');
			};
		}
		
		
		var authReader = generateAuthorizationHeader(null,request_token,'post','https://api.twitter.com/oauth/access_token',params);
		$.ajax({
	        url:'https://api.twitter.com/oauth/access_token',
	        type:'post',
	        headers:{
	        	"Authorization": authReader
	        },
	        success:success,
	        error:errorCallback
	    }); 
	}


	/**
	 * Posta uma mensagem no twitter (Publica um novo status) 
	 *
	 * @msg - A mensagem a ser publicada
	 * @param access_token - O token de acesso obtido através de generateAccessToken
	 * @param token_secret - O segredo do token de acesso obtido através de generateAccessToken
	 * @param successCallback - callback a ser executado caso a operação seja bem sucedida. Recebe como parâmetro um objeto com as informações da página.
	 * @param failCallback - Callback a ser executado caso haja uma falha ao executar a operação.
	 */
	this.tweetMsg = function(msg, access_token, token_secret, successCallback, failCallback){
		var param   = new Object();
		param.key   = 'status';
		param.value = msg;

		var params = [];
		params.push(param);

		var errorCallback = failCallback;
		if(!errorCallback){
			errorCallback = function(){
				mAlert('Falha na conexão com o Twitter.');
			};
		}		
		
		var authReader = generateAuthorizationHeader(token_secret,access_token,'post','https://api.twitter.com/1.1/statuses/update.json',params);
		$.ajax({
	        url:'https://api.twitter.com/1.1/statuses/update.json',
	        type:'post',
	        headers:{
	        	"Authorization": authReader
	        },
	        data:{"status":msg},
	        success:successCallback,
	        error:errorCallback
	    }); 
	}


	//--------------------------------------------------------------


	/**
	 * Gera string aleatoria de 32 caracteres
	 */
	function generateNonce(){
		var aux = ''+Math.random();
		aux = aux.substr(2);

		var aux2 = new Date();
		aux2 = '' + aux2.getTime();

		var final = aux+''+aux2;
		if(final.length < 32){	
			final = final + '' +aux;
		}
		return final.substr(final.length-32);
	}

	function generateTimestamp(){
		var date = new Date();
		return (date.getTime()/1000).toFixed();
	}

	function generateSignature(token_secret, requestMethod, url, params){
		var signinKey   = generateSigningKey(oauth_consumer_secret,token_secret);
		var signBaseStr = generateSignatureBaseStr(requestMethod, url, params);

		var sha  = new jsSHA(signBaseStr,'ASCII');
		return sha.getHMAC(signinKey,'TEXT','SHA-1','B64');
	}

	function generateAuthorizationHeader(token_secret,oauth_token, requestMethod, url, _params){
		var nonce     = generateNonce();
		var timeStamp = generateTimestamp();

		var params = [];
		for(var i in _params){
			params.push(_params[i]);
		}

		params.push({key:'oauth_consumer_key', value:oauth_consumer_key});
		params.push({key:'oauth_nonce'       , value:nonce});
		params.push({key:'oauth_signature_method', value:oauth_signature_method});
		params.push({key:'oauth_timestamp'   , value:timeStamp});
		if(oauth_token)
		   params.push({key:'oauth_token'       , value:oauth_token});
		params.push({key:'oauth_version'     , value:oauth_version});


		var DST = 'OAuth ';

		for(var i in params){
			if(DST !== 'OAuth ')
				DST+=  ', ';
			DST += percentEncode(params[i].key)+'="'+percentEncode(params[i].value)+'"';
		}
		DST += ", "+percentEncode('oauth_signature')        + '="' +percentEncode(generateSignature(token_secret, requestMethod, url, params))+ '" ';

		return DST;
	}	


	function encodeParams(params){

		var encodedValues=[];
		var encodedKeys  = [];
		for(var i in params){
			if(params[i]){
				
				var param         = params[i];
				var encoded = new Object();
				encoded.key   = percentEncode(param.key);
				encoded.value = percentEncode(param.value);

				encodedKeys.push(encoded.key);
				encodedValues[encoded.key] = encoded.value;
			}
		}
		encodedKeys.sort();
		
		var outStr = "";

		for(var i in encodedKeys){
			if(outStr)
				outStr+="&";

			outStr+=(encodedKeys[i]+'='+encodedValues[encodedKeys[i]]);
		}
		return outStr;
	}


	function percentEncode(str){ 
		var tmp = encodeURIComponent(str); 
		tmp = tmp.replace('!','%21'); 
		tmp = tmp.replace('*','%2A'); 
		tmp = tmp.replace('(','%28'); 
		tmp = tmp.replace(')','%29'); 
		tmp = tmp.replace("'",'%27'); 
		return tmp; 
	} 

	function generateSignatureBaseStr(requestMethod, url, params){
		var encodedParams = encodeParams(params);
		return requestMethod.toUpperCase() + '&' + percentEncode(url) + '&' + percentEncode(encodedParams);
	}

	function generateSigningKey(consumer_secret,token_secret){
		return percentEncode(consumer_secret)+'&'+(token_secret ? percentEncode(token_secret) : '');
	}

	
}